cuDDL
Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | Friends | List of all members
cuddl::detail::summary_payload Struct Reference

Per-thread accumulator feeding a CUB block reduction for fused summaries. More...

Collaboration diagram for cuddl::detail::summary_payload:
[legend]

Public Member Functions

__device__ summary_payload & operator+= (summary_payload const &other) noexcept
 Accumulates other into this instance for block reductions.
 

Public Attributes

pairwise_counts counts {}
 
uint64_t empty {}
 
double restored_sum {}
 

Friends

__device__ summary_payload operator+ (summary_payload left, summary_payload const &right) noexcept
 Sums two accumulators for CUB block reductions.
 

Detailed Description

Per-thread accumulator feeding a CUB block reduction for fused summaries.

Definition at line 34 of file kernels.cuh.

Member Function Documentation

◆ operator+=()

__device__ summary_payload & cuddl::detail::summary_payload::operator+= ( summary_payload const &  other)
inlinenoexcept

Accumulates other into this instance for block reductions.

Definition at line 40 of file kernels.cuh.

40 {
41 counts += other.counts;
42 empty += other.empty;
43 restored_sum += other.restored_sum;
44 return *this;
45 }

Friends And Related Symbol Documentation

◆ operator+

__device__ summary_payload operator+ ( summary_payload  left,
summary_payload const &  right 
)
friend

Sums two accumulators for CUB block reductions.

Definition at line 49 of file kernels.cuh.

49 {
50 return left += right;
51 }

Member Data Documentation

◆ counts

pairwise_counts cuddl::detail::summary_payload::counts {}

Definition at line 35 of file kernels.cuh.

35{};

◆ empty

uint64_t cuddl::detail::summary_payload::empty {}

Definition at line 36 of file kernels.cuh.

36{};

◆ restored_sum

double cuddl::detail::summary_payload::restored_sum {}

Definition at line 37 of file kernels.cuh.

37{};

The documentation for this struct was generated from the following file: